@@ -1,9 +1,9 @@
-from gismap.lab.lab import (
-    Lab as Lab,
-    ListLab as ListLab,
+from gismap.lab.labmap import (
+    LabMap as Map,
+    ListMap as ListMap,
 )
-from gismap.lab.lip6 import Lip6 as Lip6, Lip6Lab as Lip6Lab
-from gismap.lab.toulouse import Solace as Solace, LaasLab as LaasLab
+from gismap.lab.lip6 import Lip6Full as Lip6Full, Lip6Map as Lip6
+from gismap.lab.toulouse import SolaceMap as Solace, LaasMap as Laas
 from gismap.lab.graph import lab2graph as lab2graph
 from gismap.lab.vis import generate_html as generate_html
 from gismap.lab.egomap import EgoMap as EgoMap
