@@ -1,12 +1,12 @@
 from bs4 import BeautifulSoup as Soup
 import re
 
-from gismap.lab.lab import Lab
+from gismap.lab.labmap import LabMap
 from gismap.lab.lab_author import AuthorMetadata, LabAuthor
 from gismap.utils.requests import get
 
 
-class Lip6Lab(Lab):
+class Lip6Map(LabMap):
     """
     Class for handling a LIP6 team using `https://www.lip6.fr/recherche/team_membres.php?acronyme=*team_acronym*` as entry point.
     Default to `NPA` team.
@@ -25,10 +25,14 @@ class Lip6Lab(Lab):
             previous = a.find_previous_sibling()
             if previous is not None and "user" in previous.get("class", []):
                 metadata.url = previous["href"].strip()
+            fiche = "https://www.lip6.fr/" + a["href"].split("/", 1)[1]
+            img = Soup(get(fiche), "lxml").img
+            if img and "reflet" in img["class"] and "noPhoto" not in img["src"]:
+                metadata.img = "https://www.lip6.fr/" + img["src"].split("/", 1)[1]
             yield LabAuthor(name=name, metadata=metadata)
 
 
-class Lip6(Lip6Lab):
+class Lip6Full(Lip6Map):
     """
     Class for handling all LIP6 teams using `https://www.lip6.fr/informations/annuaire.php` to get team names.
     """
@@ -40,5 +44,5 @@ class Lip6(Lip6Lab):
         for group in groups.findall(
             get("https://www.lip6.fr/informations/annuaire.php")
         ):
-            for author in Lip6Lab(name=group)._author_iterator():
+            for author in Lip6Map(name=group)._author_iterator():
                 yield author
